function render(offset) {
  var _ref = <div tabIndex={offset + 1} />;

  return function () {
    return _ref;
  };
}
